@@ -8,5 +8,6 @@ config = {
     # this is the CIK of the portal. It can be found in your portal under
     # Account > Portals
     # Look for: Key: 123abc...
-    'portalcik': 'baa1f6617dd7ea8b6200648251d97926d972b75c'
+    'portalcik': 'baa1f6617dd7ea8b6200648251d97926d972b75c',
+    'cloneportalcik': 'baa1f6617dd7ea8b6200648251d97926d972b75c'
 }
